@@ -67,6 +67,7 @@ func (a *App) List(ctx context.Context, limit int, exporter cmdutil.Exporter) er
 	tp := utils.NewTablePrinter(a.io)
 	if tp.IsTTY() {
 		tp.AddField("NAME", nil, nil)
+		tp.AddField("DISPLAY NAME", nil, nil)
 		tp.AddField("REPOSITORY", nil, nil)
 		tp.AddField("BRANCH", nil, nil)
 		tp.AddField("STATE", nil, nil)
@@ -102,6 +103,7 @@ func (a *App) List(ctx context.Context, limit int, exporter cmdutil.Exporter) er
 		}
 
 		tp.AddField(formattedName, nil, nameColor)
+		tp.AddField(c.DisplayName, nil, nil)
 		tp.AddField(c.Repository.FullName, nil, nil)
 		tp.AddField(c.branchWithGitStatus(), nil, cs.Cyan)
 		if c.PendingOperation {
