@@ -2,7 +2,7 @@ package extension
 
 import (
 	"errors"
-	"io/ioutil"
+	"io"
 	"net/http"
 	"os"
 	"strings"
@@ -273,8 +273,9 @@ func TestNewCmdExtension(t *testing.T) {
 					assert.Equal(t, "", calls[0].Name)
 				}
 			},
-			isTTY:      true,
-			wantStderr: "! No installed extensions found\n",
+			isTTY:   true,
+			wantErr: true,
+			errMsg:  "no installed extensions found",
 		},
 		{
 			name: "upgrade all notty",
@@ -550,8 +551,8 @@ func TestNewCmdExtension(t *testing.T) {
 
 			cmd := NewCmdExtension(&f)
 			cmd.SetArgs(tt.args)
-			cmd.SetOut(ioutil.Discard)
-			cmd.SetErr(ioutil.Discard)
+			cmd.SetOut(io.Discard)
+			cmd.SetErr(io.Discard)
 
 			_, err := cmd.ExecuteC()
 			if tt.wantErr {
