@@ -195,7 +195,7 @@ func printHumanIssuePreview(opts *ViewOptions, issue *api.Issue) error {
 	fmt.Fprintf(out, "%s #%d\n", cs.Bold(issue.Title), issue.Number)
 	fmt.Fprintf(out,
 		"%s • %s opened %s • %s\n",
-		issueStateTitleWithColor(cs, issue.State),
+		issueStateTitleWithColor(cs, issue),
 		issue.Author.Login,
 		utils.FuzzyAgo(ago),
 		utils.Pluralize(issue.Comments.TotalCount, "comment"),
@@ -254,9 +254,9 @@ func printHumanIssuePreview(opts *ViewOptions, issue *api.Issue) error {
 	return nil
 }
 
-func issueStateTitleWithColor(cs *iostreams.ColorScheme, state string) string {
-	colorFunc := cs.ColorFromString(prShared.ColorForState(state))
-	return colorFunc(strings.Title(strings.ToLower(state)))
+func issueStateTitleWithColor(cs *iostreams.ColorScheme, issue *api.Issue) string {
+	colorFunc := cs.ColorFromString(prShared.ColorForIssueState(*issue))
+	return colorFunc(strings.Title(strings.ToLower(issue.State)))
 }
 
 func issueAssigneeList(issue api.Issue) string {
