@@ -18,7 +18,9 @@ type RerunOptions struct {
 	IO         *iostreams.IOStreams
 	BaseRepo   func() (ghrepo.Interface, error)
 
-	RunID string
+	RunID      string
+	OnlyFailed bool
+	JobID      string
 
 	Prompt bool
 }
@@ -37,12 +39,18 @@ func NewCmdRerun(f *cmdutil.Factory, runF func(*RerunOptions) error) *cobra.Comm
 			// support `-R, --repo` override
 			opts.BaseRepo = f.BaseRepo
 
-			if len(args) > 0 {
+			if len(args) == 0 && opts.JobID == "" {
+				if !opts.IO.CanPrompt() {
+					return cmdutil.FlagErrorf("`<run-id>` or `--job` required when not running interactively")
+				} else {
+					opts.Prompt = true
+				}
+			} else if len(args) > 0 {
 				opts.RunID = args[0]
-			} else if !opts.IO.CanPrompt() {
-				return cmdutil.FlagErrorf("run ID required when not running interactively")
-			} else {
-				opts.Prompt = true
+			}
+
+			if opts.RunID != "" && opts.JobID != "" {
+				return cmdutil.FlagErrorf("specify only one of `<run-id>` or `--job`")
 			}
 
 			if runF != nil {
@@ -52,6 +60,9 @@ func NewCmdRerun(f *cmdutil.Factory, runF func(*RerunOptions) error) *cobra.Comm
 		},
 	}
 
+	cmd.Flags().BoolVar(&opts.OnlyFailed, "failed", false, "Rerun only failed jobs, including dependencies")
+	cmd.Flags().StringVarP(&opts.JobID, "job", "j", "", "Rerun a specific job from a run, including dependencies")
+
 	return cmd
 }
 
@@ -67,10 +78,23 @@ func runRerun(opts *RerunOptions) error {
 		return fmt.Errorf("failed to determine base repo: %w", err)
 	}
 
+	cs := opts.IO.ColorScheme()
+
 	runID := opts.RunID
+	jobID := opts.JobID
+	var selectedJob *shared.Job
+
+	if jobID != "" {
+		opts.IO.StartProgressIndicator()
+		selectedJob, err = shared.GetJob(client, repo, jobID)
+		opts.IO.StopProgressIndicator()
+		if err != nil {
+			return fmt.Errorf("failed to get job: %w", err)
+		}
+		runID = fmt.Sprintf("%d", selectedJob.RunID)
+	}
 
 	if opts.Prompt {
-		cs := opts.IO.ColorScheme()
 		runs, err := shared.GetRunsWithFilter(client, repo, nil, 10, func(run shared.Run) bool {
 			if run.Status != shared.Completed {
 				return false
@@ -83,7 +107,7 @@ func runRerun(opts *RerunOptions) error {
 			return fmt.Errorf("failed to get runs: %w", err)
 		}
 		if len(runs) == 0 {
-			return errors.New("no recent runs have failed; please specify a specific run ID")
+			return errors.New("no recent runs have failed; please specify a specific `<run-id>`")
 		}
 		runID, err = shared.PromptForRun(cs, runs)
 		if err != nil {
@@ -91,30 +115,73 @@ func runRerun(opts *RerunOptions) error {
 		}
 	}
 
-	opts.IO.StartProgressIndicator()
-	run, err := shared.GetRun(client, repo, runID)
-	opts.IO.StopProgressIndicator()
-	if err != nil {
-		return fmt.Errorf("failed to get run: %w", err)
-	}
-
-	path := fmt.Sprintf("repos/%s/actions/runs/%d/rerun", ghrepo.FullName(repo), run.ID)
-
-	err = client.REST(repo.RepoHost(), "POST", path, nil, nil)
-	if err != nil {
-		var httpError api.HTTPError
-		if errors.As(err, &httpError) && httpError.StatusCode == 403 {
-			return fmt.Errorf("run %d cannot be rerun; its workflow file may be broken.", run.ID)
+	if opts.JobID != "" {
+		err = rerunJob(client, repo, selectedJob)
+		if err != nil {
+			return err
+		}
+		if opts.IO.IsStdoutTTY() {
+			fmt.Fprintf(opts.IO.Out, "%s Requested rerun of job %s on run %s\n",
+				cs.SuccessIcon(),
+				cs.Cyanf("%d", selectedJob.ID),
+				cs.Cyanf("%d", selectedJob.RunID))
+		}
+	} else {
+		opts.IO.StartProgressIndicator()
+		run, err := shared.GetRun(client, repo, runID)
+		opts.IO.StopProgressIndicator()
+		if err != nil {
+			return fmt.Errorf("failed to get run: %w", err)
 		}
-		return fmt.Errorf("failed to rerun: %w", err)
-	}
 
-	if opts.IO.CanPrompt() {
-		cs := opts.IO.ColorScheme()
-		fmt.Fprintf(opts.IO.Out, "%s Requested rerun of run %s\n",
-			cs.SuccessIcon(),
-			cs.Cyanf("%d", run.ID))
+		err = rerunRun(client, repo, run, opts.OnlyFailed)
+		if err != nil {
+			return err
+		}
+		if opts.IO.IsStdoutTTY() {
+			onlyFailedMsg := ""
+			if opts.OnlyFailed {
+				onlyFailedMsg = "(failed jobs) "
+			}
+			fmt.Fprintf(opts.IO.Out, "%s Requested rerun %sof run %s\n",
+				cs.SuccessIcon(),
+				onlyFailedMsg,
+				cs.Cyanf("%d", run.ID))
+		}
 	}
 
 	return nil
 }
+
+func rerunRun(client *api.Client, repo ghrepo.Interface, run *shared.Run, onlyFailed bool) error {
+	runVerb := "rerun"
+	if onlyFailed {
+		runVerb = "rerun-failed-jobs"
+	}
+
+	path := fmt.Sprintf("repos/%s/actions/runs/%d/%s", ghrepo.FullName(repo), run.ID, runVerb)
+
+	err := client.REST(repo.RepoHost(), "POST", path, nil, nil)
+	if err != nil {
+		var httpError api.HTTPError
+		if errors.As(err, &httpError) && httpError.StatusCode == 403 {
+			return fmt.Errorf("run %d cannot be rerun; its workflow file may be broken", run.ID)
+		}
+		return fmt.Errorf("failed to rerun: %w", err)
+	}
+	return nil
+}
+
+func rerunJob(client *api.Client, repo ghrepo.Interface, job *shared.Job) error {
+	path := fmt.Sprintf("repos/%s/actions/jobs/%d/rerun", ghrepo.FullName(repo), job.ID)
+
+	err := client.REST(repo.RepoHost(), "POST", path, nil, nil)
+	if err != nil {
+		var httpError api.HTTPError
+		if errors.As(err, &httpError) && httpError.StatusCode == 403 {
+			return fmt.Errorf("job %d cannot be rerun", job.ID)
+		}
+		return fmt.Errorf("failed to rerun: %w", err)
+	}
+	return nil
+}
